﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Data;

namespace SessionHunter.Converters
{
    /// <summary>
    /// True if the value passed in is greater than zero
    /// </summary>
    public class GreaterThanZeroConverter : IValueConverter
    {
        #region IValueConverter Members

        /// <summary>
        /// Converts a value to true if greater than zero.
        /// </summary>
        /// <param name="value">The value produced by the binding source.</param>
        /// <param name="targetType">The type of the binding target property.</param>
        /// <param name="parameter">The converter parameter to use.</param>
        /// <param name="culture">The culture to use in the converter.</param>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        public object Convert(object value, Type targetType, object parameter,
            System.Globalization.CultureInfo culture)
        {
            double val;

            // Try to convert it to double, because that covers most numerical cases
            if (double.TryParse(value.ToString(), out val))
            {
                return val > 0;
            }

            // Return false, because we cannot parse it
            return false;
        }

        /// <summary>
        /// Not supported
        /// </summary>
        /// <param name="value">The value that is produced by the binding target.</param>
        /// <param name="targetType">The type to convert to.</param>
        /// <param name="parameter">The converter parameter to use.</param>
        /// <param name="culture">The culture to use in the converter.</param>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        public object ConvertBack(object value, Type targetType, object parameter,
            System.Globalization.CultureInfo culture)
        {
            throw new NotSupportedException();
        }

        #endregion
    }
}
